@@ -14,7 +14,7 @@ prhead_semaphore()
 }
 
 void
-__print_semaphore(semp)
+mprint_semaphore(semp)
 	struct semaphore *semp;
 {
 	mprintf("%4d %5d", ATOMIC_READ(semp->count), semp->waking);
@@ -28,7 +28,7 @@ addr_t addr;
 
 	memread(addr, sizeof(struct semaphore), &sem, "semaphore");
 	mprintf(FPTR " ", addr);
-	__print_semaphore(&sem);
+	mprint_semaphore(&sem);
 	mprintf("\n");
 	return ATOMIC_READ(sem.count);
 }
