@@ -27,3 +27,19 @@ addr_t addr;
 	mprintf("\n");
 	return (addr_t)vm.next;
 }
+
+addr_t
+search_from_vm(addr, search)
+addr_t addr, search;
+{
+	struct vm_struct vm;
+
+	memread(addr, sizeof(addr_t), &addr, "vmlist");
+	while (addr) {
+		memread(addr, sizeof(struct vm_struct), &vm, "vm_struct");
+		if ((addr_t)vm.addr <= search && (addr_t)vm.addr + vm.size > search)
+			return addr;
+		addr = (addr_t)vm.next;
+	}
+	return 0;
+}
