@@ -11,12 +11,21 @@ extern const commandtable_t
 	command_char_device,
 	command_exception_table,
 	command_ext2_inode_info,
+#if defined(CONFIG_EXT3_FS) || defined(CONFIG_EXT3_FS_MODULE)
+	command_ext3_sb_info,
+#endif
 	command_fib_table,
 	command_file,
 	command_file_lock,
 	command_files_stat,
 	command_gendisk,
+#if defined(CONFIG_JBD) || defined(CONFIG_JBD_MODULE)
+	command_handle,
+#endif
 	command_inode,
+#if defined(CONFIG_JBD) || defined(CONFIG_JBD_MODULE)
+	command_journal,
+#endif
 	command_kmem_cache,
 	command_lv,
 	command_neighbour,
@@ -69,12 +78,21 @@ const commandtable_t *commandtable_vers[] = {
 #endif
 	&command_exception_table,
 	&command_ext2_inode_info,
+#if defined(CONFIG_EXT3_FS) || defined(CONFIG_EXT3_FS_MODULE)
+	&command_ext3_sb_info,
+#endif
 	&command_fib_table,
 	&command_file,
 	&command_file_lock,
 	&command_files_stat,
 	&command_gendisk,
+#if defined(CONFIG_JBD) || defined(CONFIG_JBD_MODULE)
+	&command_handle,
+#endif
 	&command_inode,
+#if defined(CONFIG_JBD) || defined(CONFIG_JBD_MODULE)
+	&command_journal,
+#endif
 	&command_kmem_cache,
 #if defined(CONFIG_BLK_DEV_LVM) || defined(CONFIG_BLK_DEV_LVM_MODULE)
 	&command_lv,
