@@ -45,6 +45,12 @@ print_bio(addr, full)
 		{ 1<<BIO_SEG_VALID,	"seg_valid" },
 		{ 1<<BIO_CLONED,	"cloned" },
 		{ 1<<BIO_BOUNCED,	"bounced" },
+#ifdef BIO_USER_MAPPED
+		{ 1<<BIO_USER_MAPPED,	"user_mapped" },
+#endif
+#ifdef BIO_EOPNOTSUPP
+		{ 1<<BIO_EOPNOTSUPP,	"enpnosupp" },
+#endif
 		{ 0,			NULL }
 	};
 
