@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000-2003 ASANO Masahiro
+ * Copyright (C) 2000-2007 ASANO Masahiro
  */
 
 #include "def.h"
@@ -31,6 +31,9 @@ print_request_queue(addr, full)
 		mprintf(FPTR "  " FPTR "\n",
 			rq.queue_head.next, rq.queue_head.prev);
 
+#ifdef _request_queue_has_last_merge
+	mprintf("last_merge:        " FPTR "\n", rq.last_merge);
+#endif
 #if _request_queue_has_elevator == 0
 	mprintf("elevator:          " FPTR "  %s\n", rq.elevator,
 		(p = getsymstr_func((addr_t)rq.elevator))? p: "");
@@ -56,12 +59,18 @@ print_request_queue(addr, full)
 
 	mprintf("request_fn:        " FPTR "  %s\n", rq.request_fn,
 		(p = getsymstr_func((addr_t)rq.request_fn))? p: "");
+#if _request_queue_has_merge_fn
 	mprintf("back_merge_fn:     " FPTR "  %s\n", rq.back_merge_fn,
 		(p = getsymstr_func((addr_t)rq.back_merge_fn))? p: "");
+#endif
+#if _request_queue_has_front_merge_fn
 	mprintf("front_merge_fn:    " FPTR "  %s\n", rq.front_merge_fn,
 		(p = getsymstr_func((addr_t)rq.front_merge_fn))? p: "");
+#endif
+#if _request_queue_has_merge_requests_fn
 	mprintf("merge_requests_fn: " FPTR "  %s\n", rq.merge_requests_fn,
 		(p = getsymstr_func((addr_t)rq.merge_requests_fn))? p: "");
+#endif
 	mprintf("make_request_fn:   " FPTR "  %s\n", rq.make_request_fn,
 		(p = getsymstr_func((addr_t)rq.make_request_fn))? p: "");
 	mprintf("prep_rq_fn:        " FPTR "  %s\n", rq.prep_rq_fn,
@@ -71,6 +80,18 @@ print_request_queue(addr, full)
 	mprintf("merge_bvec_fn:     " FPTR "  %s\n", rq.merge_bvec_fn,
 		(p = getsymstr_func((addr_t)rq.merge_bvec_fn))? p: "");
 	mprintf("queuedata:         " FPTR "\n", rq.queuedata);
+#if _request_queue_has_issue_flush_fn
+	mprintf("issue_flush_fn:    " FPTR "  %s\n", rq.issue_flush_fn,
+		(p = getsymstr_func((addr_t)rq.issue_flush_fn))? p: "");
+#endif
+#if _request_queue_has_prepare_flush_fn
+	mprintf("issue_prepare_fn:  " FPTR "  %s\n", rq.prepare_flush_fn,
+		(p = getsymstr_func((addr_t)rq.prepare_flush_fn))? p: "");
+#endif
+#if _request_queue_has_softirq_done_fn
+	mprintf("softirq_done_fn:   " FPTR "  %s\n", rq.softirq_done_fn,
+		(p = getsymstr_func((addr_t)rq.softirq_done_fn))? p: "");
+#endif
 
 #ifdef _request_queue_has_plug_list
 	mprintf("plug_list:         ");
