@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000-2005 ASANO Masahiro
+ * Copyright (C) 2000-2007 ASANO Masahiro
  */
 
 #include "def.h"
@@ -144,7 +144,9 @@ print_file(addr, full)
 		mprintf("\tvfsmnt:     " FPTR "  (vfsmount)\n", f.f_vfsmnt);
 		mprintf("\towener.pid: %x\n", f.f_owner.pid);
 		mprintf("\tversion:    %lx\n", f.f_version);
+#ifdef _file_has_f_security
 		mprintf("\tsecurity    " FPTR "\n", f.f_security);
+#endif
 #ifdef _file_has_f_mapping
 		mprintf("\tmapping:    " FPTR "  (address_space)\n", f.f_mapping);
 #endif
@@ -274,7 +276,7 @@ print_inode(addr, full)
 #ifdef _inode_has_i_security
 		mprintf("\tsecurity:  " FPTR "\n", inode.i_security);
 #endif
-#if SUBLEVEL>=19 || defined(_inode_has_i_private)
+#ifdef _inode_has_i_private
 		mprintf("\tprivate:   " FPTR "\n", inode.i_private);
 #else
 		mprintf("\tgeneric_ip:" FPTR "\n", inode.u.generic_ip);
