@@ -16,8 +16,13 @@ void
 prhead_zone()
 {
 #ifndef _zone_has_zone_mem_map
+#ifndef _zone_has_free_pages
+	mprintf(SPTR" SCANAC "SPTR" STARTPFN PAGES NAME\n",
+		"ADDR", "PGDAT");
+#else
 	mprintf(SPTR" FREEPG "SPTR" STARTPFN PAGES NAME\n",
 		"ADDR", "PGDAT");
+#endif
 #else
 	mprintf(SPTR" FREEPG "SPTR" "SPTR" STARTPFN PAGES NAME\n",
 		"ADDR", "PGDAT", "MEM_MAP");
@@ -35,8 +40,13 @@ print_zone(addr, full)
 
 	memread(addr, sizeof(zone), &zone, "zone");
 	if (!full) {
-		mprintf(FPTR " %6lx " FPTR " ",
-			addr, zone.free_pages, zone.zone_pgdat);
+		mprintf(FPTR, addr);
+#ifndef _zone_has_free_pages
+		mprintf(" %6lx ", zone.nr_scan_active);
+#else
+		mprintf(" %6lx ", zone.free_pages);
+#endif
+		mprintf(FPTR " ", zone.zone_pgdat);
 #ifdef _zone_has_zone_mem_map
 		mprintf(FPTR " ", zone.zone_mem_map);
 #endif
@@ -54,12 +64,19 @@ print_zone(addr, full)
 		return 0;
 	}
 
+#ifdef _zone_has_free_pages
 	mprintf("free_pages         %lx\n", zone.free_pages);
+#endif
 	mprintf("pages_min/low/high %lx/%lx/%lx\n",
 		zone.pages_min, zone.pages_low, zone.pages_high);
 #ifdef _zone_has_nr_scan_active
+#ifndef _zone_has_nr_active
+	mprintf("nr_scan_active     %lx\n", zone.nr_scan_active);
+	mprintf("nr_scan_inactive   %lx\n", zone.nr_scan_inactive);
+#else
 	mprintf("nr_active (scan)   %lx  (%lx)\n", zone.nr_active, zone.nr_scan_active);
 	mprintf("nr_inactive (scan) %lx  (%lx)\n", zone.nr_inactive, zone.nr_scan_inactive);
+#endif
 #else
 	mprintf("nr_active          %lx\n", zone.nr_active);
 	mprintf("nr_inactive        %lx\n", zone.nr_inactive);
