@@ -1,12 +1,15 @@
 /*
- * Copyright (C) 2000-2002 ASANO Masahiro
+ * Copyright (C) 2000-2007 ASANO Masahiro
  */
 
 #include "def.h"
 
 #define __KERNEL__
 #include <linux/fs.h>
+#include <linux/sched.h>
+#if SUBLEVEL<=19
 #include <linux/namespace.h>
+#endif
 #include <linux/mount.h>
 
 #include "flags_sched.h"
@@ -21,6 +24,7 @@ addr_t
 print_namespace(addr)
 	addr_t addr;
 {
+#ifdef _namespace_has_list
 	struct namespace ns;
 
 	if (addr == 0) {
@@ -47,4 +51,8 @@ print_namespace(addr)
 	}
 	mprintf("\n");
 	return (addr_t)ns.list.next;
+
+#else
+	return 0;
+#endif /*front_merge_fn*/
 }
