@@ -31,7 +31,7 @@ print_slab(addr, num)
 {
 #ifndef NO_SUCH_FILE
 	struct slab slab;
-	kmem_bufctl_t buf[512], ix = slab.free;
+	kmem_bufctl_t buf[512], ix = slab.free, prev = -1;
 
 	memread(addr, sizeof(slab), &slab, "slab_t");
 	mprintf(FPTR " ", addr);
@@ -55,10 +55,11 @@ print_slab(addr, num)
 			mprintf(" %x", ix);
 			if (buf[ix] == BUFCTL_END)
 				break;
-			else if (buf[ix] == ix) {
+			else if (buf[ix] == ix ||  buf[ix] == prev) {
 				mprintf("...?\n");
 				return 0;
 			}
+			prev = ix;
 			ix = buf[ix];
 		}
 		mprintf("\n");
@@ -141,9 +142,15 @@ print_kmem_cache(addr, sflag, full, next)
 	memread((addr_t)cache.name, sizeof(name), name, "kmem_cache_t");
 
 	if (!full) {
+#ifdef _kmem_cache_has_buffer_size
+		mprintf(FPTR " %5x %3x %4lx %4x %4x  ",
+			addr, cache.buffer_size, cache.num, cache.colour,
+			cache.colour_off, cache.batchcount);
+#else
 		mprintf(FPTR " %5x %3x %4lx %4x %4x  ",
 			addr, cache.objsize, cache.num, cache.colour,
 			cache.colour_off, cache.colour_next);
+#endif
 		mprintstr(name, sizeof(name));
 		mprintf("\n");
 
@@ -172,12 +179,21 @@ print_kmem_cache(addr, sflag, full, next)
 #if defined(_kmem_cache_has_shared) || defined(_kmem_cache_s_has_shared)
 		mprintf("shared       %x\n", cache.shared);
 #endif
+#if defined(_kmem_cache_has_buffer_size)
+		mprintf("buffer_size  %x\n", cache.buffer_size);
+#endif
+#if defined(_kmem_cache_has_objsize) || defined(_kmem_cache_s_has_objsize)
 		mprintf("objsize      %x\n", cache.objsize);
-#if defined(_kmem_cache_s_has_nodelists) ||defined(_kmem_cache_has_nodelists)
+#endif
+#if defined(_kmem_cache_has_nodelists) ||defined(_kmem_cache_s_has_nodelists)
 		mprintf("nodelists[%x]", MAX_NUMNODES);
 		{	int i;
-			for (i = 0; i < MAX_NUMNODES; i++)
-				mprintf(" " FPTR, cache.nodelists[i]);
+			for (i = 0; i < MAX_NUMNODES; i++) {
+				if (cache.nodelists[i])
+					mprintf(" " FPTR, cache.nodelists[i]);
+				else
+					mprintf(" -");
+			}
 			mprintf("\n");
 		}
 #endif
@@ -190,7 +206,9 @@ print_kmem_cache(addr, sflag, full, next)
 		mprintf("gfpflags     %x\n", cache.gfpflags);
 		mprintf("colour       %lx\n", cache.colour);
 		mprintf("colour_off   %x\n", cache.colour_off);
+#ifdef _kmem_cache_has_colour_next
 		mprintf("colour_next  %x\n", cache.colour_next);
+#endif
 		mprintf("slabp_cache   " FPTR "\n", cache.slabp_cache);
 		mprintf("dflags       %x\n", cache.dflags);
 		p = getsymstr_func((addr_t)cache.ctor);
@@ -239,8 +257,13 @@ search_slab(addr)
 	memread(cache_chain_addr, sizeof(kmaddr), &kmaddr, "cache_chain");
 	while (kmaddr && kmaddr != cache_chain_addr) {
 		memread(kmaddr - OFFSET(kmem_cache_t, next), sizeof(cache), &cache, "kmem_cache_t");
+#if defined(_kmem_cache_has_buffer_size)
+		len = cache.buffer_size * cache.num;
+#else
 		len = cache.objsize * cache.num;
+#endif
 		cnt = 0;
+		memread((addr_t)cache.name, sizeof(name), name, "kmem_cache_t");
 
 #if defined(_kmem_cache_s_has_nodelists) || defined(_kmem_cache_has_nodelists)
 		int i;
@@ -253,54 +276,68 @@ search_slab(addr)
 
 			saddr = (addr_t)nlist.slabs_full.next - OFFSET(struct slab, list);
 			while (saddr && saddr != (addr_t)cache.nodelists[i] + OFFSET(struct kmem_list3, slabs_full)) {
-				memread(saddr, sizeof(slab), &slab, "slab_t");
+				memread(saddr, sizeof(slab), &slab, name);
 				if (addr >= (addr_t)slab.s_mem && addr < (addr_t)slab.s_mem + len)
 					goto found;
-				saddr = (addr_t)slab.list.next - OFFSET(struct slab, list);
-				if (++cnt > 100000) {
-					mprintf("loop? (%lx full)\n", kmaddr);
+				if (slab.s_mem == 0) {
+					mprintf("corrupt? (%s full %lx)\n", name, saddr);
 					break;
 				}
-
+				if (++cnt > 100000) {
+					mprintf("loop? (%s full %lx)\n", name, saddr);
+					break;
+				}
+				saddr = (addr_t)slab.list.next - OFFSET(struct slab, list);
 			}
 			cnt = 0;
 			saddr = (addr_t)nlist.slabs_partial.next - OFFSET(struct slab, list);
 			while (saddr && saddr != (addr_t)cache.nodelists[i] + OFFSET(struct kmem_list3, slabs_partial)) {
-				memread(saddr, sizeof(slab), &slab, "slab_t");
+				memread(saddr, sizeof(slab), &slab, name);
 				if (addr >= (addr_t)slab.s_mem && addr < (addr_t)slab.s_mem + len)
 					goto found;
-				saddr = (addr_t)slab.list.next - OFFSET(struct slab, list);
-				if (++cnt > 100000) {
-					mprintf("loop? (%lx partial)\n", kmaddr);
+				if (slab.s_mem == 0) {
+					mprintf("corrupt? (%s partial %lx)\n", name, saddr);
 					break;
 				}
+				if (++cnt > 100000) {
+					mprintf("loop? (%s partial %lx)\n", name, saddr);
+					break;
+				}
+				saddr = (addr_t)slab.list.next - OFFSET(struct slab, list);
 			}
 		}
 
 #else /*_kmem_cache_has_nodelists*/
 		saddr = (addr_t)cache.lists.slabs_full.next - OFFSET(struct slab, list);
 		while (saddr && saddr != kmaddr - OFFSET(kmem_cache_t, next) + OFFSET(kmem_cache_t, lists.slabs_full)) {
-			memread(saddr, sizeof(slab), &slab, "slab_t");
+			memread(saddr, sizeof(slab), &slab, name);
 			if (addr >= (addr_t)slab.s_mem && addr < (addr_t)slab.s_mem + len)
 				goto found;
-			saddr = (addr_t)slab.list.next - OFFSET(struct slab, list);
+			if (slab.s_mem == 0) {
+				mprintf("corrupt? (%s full %lx)\n", name, saddr);
+				break;
+			}
 			if (++cnt > 100000) {
 				mprintf("loop? (%lx full)\n", kmaddr);
 				break;
 			}
-
+			saddr = (addr_t)slab.list.next - OFFSET(struct slab, list);
 		}
 		cnt = 0;
 		saddr = (addr_t)cache.lists.slabs_partial.next - OFFSET(struct slab, list);
 		while (saddr && saddr != kmaddr - OFFSET(kmem_cache_t, next) + OFFSET(kmem_cache_t, lists.slabs_partial)) {
-			memread(saddr, sizeof(slab), &slab, "slab_t");
+			memread(saddr, sizeof(slab), &slab, name);
 			if (addr >= (addr_t)slab.s_mem && addr < (addr_t)slab.s_mem + len)
 				goto found;
-			saddr = (addr_t)slab.list.next - OFFSET(struct slab, list);
-			if (++cnt > 100000) {
-				mprintf("loop? (%lx partial)\n", kmaddr);
+			if (slab.s_mem == 0) {
+				mprintf("corrupt? (%s partial %lx)\n", name, saddr);
 				break;
 			}
+			if (++cnt > 100000) {
+				mprintf("loop? (%s partial %lx)\n", name, saddr);
+				break;
+			}
+			saddr = (addr_t)slab.list.next - OFFSET(struct slab, list);
 		}
 #endif /*_kmem_cache_has_nodelists*/
 		kmaddr = (addr_t)cache.next.next;
@@ -308,10 +345,15 @@ search_slab(addr)
 
 	return 0;	/* not found */
 found:
-	memread((addr_t)cache.name, sizeof(name), name, "kmem_cache_t");
+#if defined(_kmem_cache_has_buffer_size)
+	n = (addr - (addr_t)slab.s_mem) / cache.buffer_size;
+	mprintf("slab \"%s\" offset %lx ", name,
+		(addr - (addr_t)slab.s_mem) - n * cache.buffer_size);
+#else
 	n = (addr - (addr_t)slab.s_mem) / cache.objsize;
 	mprintf("slab \"%s\" offset %lx ", name,
 		(addr - (addr_t)slab.s_mem) - n * cache.objsize);
+#endif
 
 	if (slab.free == BUFCTL_END) {
 		mprintf("inuse\n");
