@@ -5,6 +5,7 @@
 #include "def.h"
 
 #define __KERNEL__ 1
+#define KBUILD_MODNAME "mcrash"
 #include <linux/usb.h>
 
 PRIVATE const char *
@@ -309,6 +310,20 @@ print_usb_interface(addr, full)
 	mprintf("driver         " FPTR "  (usb_driver)\n", ui.driver);
 #endif
 	mprintf("minor          %x\n", ui.minor);
+#ifdef _usb_interface_has_class_dev
 	mprintf("class_dev      " FPTR "\n", ui.class_dev);
+#endif
+#ifdef _usb_interface_has_condition
+	mprintf("condition      %x\n", ui.condition);
+#endif
+#ifdef _usb_interface_has_is_active
+	mprintf("is_active      %x\n", ui.is_active);
+#endif
+#ifdef _usb_interface_has_usb_dev
+	mprintf("usb_dev        " FPTR "\n", ui.usb_dev);
+#endif
+#ifdef _usb_interface_has_pm_usage_cnt
+	mprintf("pm_usage_cnt   %x\n", ui.pm_usage_cnt);
+#endif
 	return 0;
 }
