@@ -7,6 +7,8 @@
 #define __KERNEL__
 #include <linux/wait.h>
 
+#include "flags_wait.h"
+
 void
 prhead_wait_queue()
 {
@@ -24,7 +26,12 @@ print_wait_queue(addr, full)
 	memread(addr, sizeof(wq), &wq, "wait_queue_t");
 	mprintf(FPTR " ", addr);
 
-	mprintf("%02x " FPTR "\n", wq.flags, wq.task);
+	mprintf("%02x ", wq.flags);
+#ifdef ___wait_queue_has_private
+	mprintf(FPTR "\n", wq.private);
+#else
+	mprintf(FPTR "\n", wq.task);
+#endif
 	return (addr_t)wq.task_list.next;
 }
 void
