@@ -15,7 +15,7 @@ PRIVATE addr_t
 ext2_inode_info()
 {
 	int c;
-	int iflag;
+	int iflag = 0;
 
 	while ((c = getopt(argcnt, args, "i")) != EOF) {
 		switch (c) {
