@@ -20,6 +20,7 @@ extern addr_t print_page();
 extern addr_t print_vm_area_struct();
 extern addr_t print_zone();
 extern addr_t print_pglist_data();
+extern addr_t get_pglist_data_next();
 extern void print_zone_active_list();
 extern addr_t get_zone_from_pglist_data();
 extern int sizeof_page;
@@ -46,14 +47,14 @@ page()
 		}
 	}
 
-	GETADDR(mem_map);
-	if (mem_map == 0) {
-		memread(mem_map_addr, sizeof(mem_map), &mem_map, "mem_map");
-	}
-
 	if (nflag) {
 		if (argcnt == optind)
 			THROW(usage);
+		GETADDR(mem_map);
+		if (mem_map == 0) {
+			memread(mem_map_addr, sizeof(mem_map),
+				&mem_map, "mem_map");
+		}
 		prhead_page();
 		for (i = optind; i < argcnt; i++) {
 			addr = print_page(mem_map + sizeof_page * getvalue(args[i]), 0);
@@ -75,8 +76,11 @@ page()
 		GETADDR(pgdat_list);
 		memread(pgdat_list_addr, sizeof(zaddr), &zaddr, "pgdat_list");
 		prhead_page();
-		for (i = 0; (addr = get_zone_from_pglist_data(zaddr, i)); i++) {
-			print_zone_active_list(addr);
+		while (zaddr) {
+			for (i = 0; (addr = get_zone_from_pglist_data(zaddr, i)); i++) {
+				print_zone_active_list(addr);
+			}
+			zaddr = get_pglist_data_next(zaddr);
 		}
 		prhead_page();
 	}
@@ -130,9 +134,12 @@ zone()
 
 		GETADDR(pgdat_list);
 		memread(pgdat_list_addr, sizeof(zaddr), &zaddr, "pgdat_list");
-		prhead_zone();
-		for (i = 0; (addr = get_zone_from_pglist_data(zaddr, i)); i++) {
-			print_zone(addr, full);
+		while (zaddr) {
+			prhead_zone();
+			for (i = 0; (addr = get_zone_from_pglist_data(zaddr, i)); i++) {
+				print_zone(addr, full);
+			}
+			zaddr = get_pglist_data_next(zaddr);
 		}
 		return addr;
 	}
@@ -159,7 +166,9 @@ pglist_data()
 	if (optind == argcnt) {
 		GETADDR(pgdat_list);
 		memread(pgdat_list_addr, sizeof(addr), &addr, "pgdat_list");
-		addr = print_pglist_data(addr);
+		while (addr) {
+			addr = print_pglist_data(addr);
+		}
 	}
 	while (args[optind]) {
 		addr = print_pglist_data(getvalue(args[optind]));
