@@ -6,6 +6,7 @@
 
 #define __KERNEL__
 #include <linux/param.h>
+#include <asm/page.h>
 
 void
 mprint_HZ()
@@ -35,3 +36,12 @@ mprint_jif(jif)
 	mprintf(".%03d", (int)(jif*(1000.0/HZ)));
 #endif
 }
+
+addr_t get_page_offset()
+{
+#ifdef __START_KERNEL_map /*x86_64*/
+	return (addr_t)__START_KERNEL_map;
+#else
+	return (addr_t)PAGE_OFFSET;
+#endif
+}
