@@ -44,10 +44,16 @@ dmesg()
 	GETADDR(log_buf);
 	GETADDR(log_end);
 #if LINUXVER>=26
-	memread(log_buf_addr, sizeof(log_buf_addr), &log_buf_addr, "log_buf");
-	/* log_buf_len is variable in Linux-2.6 */ /*XXX*/
-#endif
+	{
+		/* log_buf_len is variable in Linux-2.6 */ /*XXX*/
+		addr_t log_buf_start;
+		memread(log_buf_addr, sizeof(log_buf_addr), &log_buf_start,
+			"log_buf");
+		memread(log_buf_start, LOG_BUF_LEN, buf, "log_buf");
+	}
+#else
 	memread(log_buf_addr, LOG_BUF_LEN, buf, "log_buf");
+#endif
 	memread(log_end_addr, sizeof(log_end), &log_end, "log_end");
 
 	c = '\0';
