@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000-2003 ASANO Masahiro
+ * Copyright (C) 2000-2006 ASANO Masahiro
  */
 
 #include <assert.h>
@@ -142,9 +142,9 @@ init()
 	}
 }
 
-void
+static void
 setarghist(arg)
-	const unsigned char *arg;
+	const char *arg;
 {
 	int i;
 
