@@ -38,6 +38,13 @@ addr_t high_memory;
 
 #ifdef CONF_USE_LKCD
 extern char *kerntype;
+#ifdef ARCH_ia64
+int page_shift_bits = 14;	/* 16KB */
+#else
+int page_shift_bits = 12;	/*  4KB */
+#endif
+unsigned long KL_DUMP_HEADER_SIZE = (64*1024);
+unsigned long KL_DUMP_BUFFER_SIZE = (64*1024);
 
 void *
 kl_get_ra(void)
@@ -87,6 +94,8 @@ init_mem()
 		if (kerntype == NULL) {
 			kerntype = "/boot/Kerntypes";
 		}
+		kl_set_stdout(stdout);
+		kl_set_stderr(stderr);
 		if (kl_init_klib(symname, physname, kerntype, 0)) {
 			fprintf(stderr, "abort\n");
 			exit(1);
@@ -123,12 +132,12 @@ ll_memread(addr, size, buf, errmsg)
 	{
 		loff_t off;
 		if (_llseek(mem, 0, addr, &off, SEEK_SET) == -1) {
-			THROWF2("Error: seek %d to %lx fail", mem, addr);
+			THROWF2("Error: seek to %s address %lx", errmsg, addr);
 		}
 	}
 #else
 	if (lseek(mem, (off_t)addr, SEEK_SET) != (off_t)addr) {
-		THROWF2("Error: seek %d to %lx", mem, addr);
+		THROWF2("Error: seek to %s address %lx", errmsg, addr);
 	}
 #endif
 	(void)memset(buf, '\0', size);
@@ -163,7 +172,8 @@ memread(addr, size, buf, errmsg)
 			size -= count;
 		} while (size);
 #else /*CONF_USE_LKCD*/
-		if (get_block(addr, (unsigned)size, buf, 0)) {
+//#define kl_get_block	get_block
+		if (kl_get_block(addr, (unsigned)size, buf, 0)) {
 			kl_print_error();
 			THROWF2("Error: address %lx for %s", addr, errmsg);
 		}
@@ -261,6 +271,8 @@ init_sym()
 		/* type: see info (binutils::nm) */
 		if (type == '?' && strcmp(buf, "init_task_union") != 0)
 			continue;
+		if (type == 'A' && strncmp(buf, "__crc_", 6) == 0)
+			continue;
 		/* drivers/pci/names.c */
 		if (buf[0] == '_' && buf[1] == '_' && (strncmp(buf + 2, "devices_", 8) == 0 || strncmp(buf + 2, "devicestr_", 10) == 0))
 			continue;
@@ -268,13 +280,12 @@ init_sym()
 		if (buf[0] == '.')
 			continue;
 #endif /*0*/
-#ifdef ARCH_i386
-		if (strcmp(buf, "swapper_pg_dir") == 0)
-			swapper_pg_dir = addr;
-#endif
 #ifdef ARCH_x86_64
 		if (strcmp(buf, "init_level4_pgt") == 0)
 			swapper_pg_dir = addr;
+#else
+		if (strcmp(buf, "swapper_pg_dir") == 0)
+			swapper_pg_dir = addr;
 #endif
 #if LINUXVER >= 25
 		/* for 2.5 system_call() */
@@ -560,6 +571,8 @@ getsymstr_func(addr)
 	return getsymstr(addr);
 }
 
+addr_t vmlist_addr;
+
 PRIVATE addr_t
 dsymbol()
 {
@@ -568,6 +581,7 @@ dsymbol()
 	const struct symtable *p;
 	int fault = 0;
 	int sflag = 0;
+	addr_t vmaddr;
 
 	while ((c = getopt(argcnt, args, "s")) != EOF) {
 		switch (c) {
@@ -585,6 +599,14 @@ dsymbol()
 	for (i = optind; args[i]; i++) {
 		addr = getvalue(args[i]);
 		if ((p = searchsym_byaddr(addr)) != NULL) {
+			if (sflag == 1) {
+				GETADDR(vmlist);
+				vmaddr = search_from_vm(vmlist_addr, addr);
+				if (vmaddr > p->addr) {
+					mprintf("vm_struct %lx\n", vmaddr);
+					continue;
+				}
+			}
 			if (addr == p->addr) {
 				mprintf("%s\n", p->name);
 			} else {
@@ -595,7 +617,13 @@ dsymbol()
 		} else if (search_task(addr)) {
 		} else if (search_slab(addr)) {
 		} else {
-			fault = 1;
+			GETADDR(vmlist);
+			vmaddr = search_from_vm(vmlist_addr, addr);
+			if (vmaddr) {
+				mprintf("vm_struct %lx\n", vmaddr);
+			} else {
+				fault = 1;
+			}
 		}
 	}
 	if (fault) {
