@@ -7,7 +7,7 @@
 
 PRIVATE addr_t superblock();
 const commandtable_t command_super_block =
-	{"super_block", superblock, "[address]", "print super_block table"};
+	{"super_block", superblock, "[-f] [address]", "print super_block table\n  -f   print detail\n  -ff  print file[s] associated the super_block"};
 
 addr_t super_blocks_addr;
 
@@ -17,32 +17,33 @@ PRIVATE addr_t
 superblock()
 {
 	int i, c, full = 0;
-	struct list_head super_blocks;
 	addr_t addr = 0;
 	extern void prhead_superblock();
 
 	while ((c = getopt(argcnt, args, "f")) != EOF) {
 		switch (c) {
 		case 'f':
-			full = 1;
+			full += 1;
 			break;
 		default:
 			THROW(usage);
 		}
 	}
 
-	prhead_superblock();
+	if (!full) prhead_superblock();
 
 	if (argcnt > optind) {
 		for (i = optind; i < argcnt; i++) {
-			addr = getvalue(args[i]);
-			addr = print_superblock(addr, full);
+			if (full) prhead_superblock();
+			addr = print_superblock(getvalue(args[i]), full);
 		}
 	} else {
+		struct list_head super_blocks;
 		GETADDR(super_blocks);
 		memread(super_blocks_addr, sizeof(super_blocks), &super_blocks,
 			"super_blocks");
 		for (addr = (addr_t)super_blocks.next; addr && addr != super_blocks_addr;) {
+			if (full) prhead_superblock();
 			addr = print_superblock(addr, full);
 		}
 	}
