@@ -21,6 +21,9 @@ sys_call()
 	int full;
 	int i, c;
 	const char *p;
+#ifndef NR_syscalls	/*XXX*/
+#define NR_syscalls 256
+#endif
 	addr_t table[NR_syscalls];
 
 	while ((c = getopt(argcnt, args, "f")) != EOF) {
