@@ -21,6 +21,7 @@ extern const commandtable_t
 	command_function,
 	command_help,
 	command_jiffies,
+	command_list_head,
 	command_mm_struct,
 	command_module,
 	command_print,
@@ -52,6 +53,7 @@ const commandtable_t *commandtable_base[] = {
 	&command_function,
 	&command_help,
 	&command_jiffies,
+	&command_list_head,
 	&command_mm_struct,
 	&command_module,
 	&command_print,
