@@ -10,16 +10,21 @@
 #include <xfs_log.h>
 #include <xfs_trans.h>
 #include <xfs_sb.h>
+#ifdef HAVE_XFS_DIR1
 #include <xfs_dir.h>
+#endif
 #include <xfs_dir2.h>
 #include <xfs_dmapi.h>
 #include <xfs_mount.h>
 #include <xfs_bmap_btree.h>
 #include <xfs_attr_sf.h>
+#ifdef HAVE_XFS_DIR1
 #include <xfs_dir_sf.h>
+#endif
 #include <xfs_dir2_sf.h>
 #include <xfs_dinode.h>
 #include <xfs_inode.h>
+#include <xfs_quota.h>
 
 #include "flags_mount.h"
 
@@ -40,44 +45,35 @@ print_xfs_mount(addr, flag)
 	xfs_mount_t m;
 	char name[32];
 	int i;
-#if 0
-	static const struct bitname mflags[] = {
-		{ XFS_MOUNT_WSYNC,		"wsync" },
-#ifdef XFS_MOUNT_INO64
-		{ XFS_MOUNT_INO64,		"ino64" },
+	static const struct bitname qflags[] = {
+		{ XFS_UQUOTA_ACCT,	"uquota_acct" },
+		{ XFS_UQUOTA_ENFD,	"uquota_enfd" },
+		{ XFS_UQUOTA_CHKD,	"uquota_chkd" },
+		{ XFS_PQUOTA_ACCT,	"pquota_acct" },
+#ifdef XFS_OQUOTA_ENFD
+		{ XFS_OQUOTA_ENFD,	"oquota_enfd" },
 #endif
-#ifdef XFS_MOUNT_ROOTQCHECK
-		{ XFS_MOUNT_ROOTQCHECK,		"rootqcheck" },
+#ifdef XFS_OQUOTA_CHKD
+		{ XFS_OQUOTA_CHKD,	"oquota_chkd" },
 #endif
-		{ XFS_MOUNT_FS_SHUTDOWN,	"fs_shutdown" },
-		{ XFS_MOUNT_NOATIME,		"noatime" },
-		{ XFS_MOUNT_RETERR,		"reterr" },
-		{ XFS_MOUNT_NOALIGN,		"noalign" },
-#ifdef XFS_MOUNT_REGISTERED
-		{ XFS_MOUNT_REGISTERED,		"registered" },
+#ifdef XFS_GQUOTA_ENFD
+		{ XFS_GQUOTA_ENFD,	"gquota_enfd" },
 #endif
-		{ XFS_MOUNT_NORECOVERY,		"norecovery" },
-		{ XFS_MOUNT_SHARED,		"shared" },
-		{ XFS_MOUNT_DFLT_IOSIZE,	"dflt_iosize" },
-#ifdef XFS_MOUNT_OSYNCISOSYNC
-		{ XFS_MOUNT_OSYNCISOSYNC,	"osyncisosync" },
+#ifdef XFS_GQUOTA_CHKD
+		{ XFS_GQUOTA_CHKD,	"gquota_chkd" },
 #endif
-#ifdef XFS_MOUNT_OSYNCISDSYNC
-		{ XFS_MOUNT_OSYNCISDSYNC,	"osyncisdsync" },
+		{ XFS_GQUOTA_ACCT,	"gquota_acct" },
+
+		{ XFS_UQUOTA_ACTIVE,	"uquota_active" },
+#ifdef XFS_PQUOTA_ACTIVE
+		{ XFS_PQUOTA_ACTIVE,	"pquota_active" },
 #endif
-		{ XFS_MOUNT_NOUUID,		"nouuid" },
-#ifdef XFS_MOUNT_32BITINODES
-		{ XFS_MOUNT_32BITINODES,	"32bitinodes" },
+		{ XFS_GQUOTA_ACTIVE,	"gquota_active" },
+#ifdef XFS_QUOTA_MAYBE
+		{ XFS_QUOTA_MAYBE,	"quota_maybe" },
 #endif
-#ifdef XFS_MOUNT_IRIXSGID
-		{ XFS_MOUNT_IRIXSGID,		"irixsgid" },
-#endif
-#ifdef XFS_MOUNT_NOLOGFLUSH
-		{ XFS_MOUNT_NOLOGFLUSH,		"nologflush" },
-#endif
-		{ 0,				NULL }
+		{ 0,			NULL }
 	};
-#endif
 
 	mprintf("addr         " FPTR "  (%x)\n", addr, sizeof(m));
 	memread(addr, sizeof(m), &m, "xfs_mount_t");
@@ -127,8 +123,8 @@ print_xfs_mount(addr, flag)
 	mprintf("quotainfo    " FPTR "  (xfs_quotainfo)\n", m.m_quotainfo);
 #ifdef _xfs_mount_has_m_logdev_targp
 	/* new style */
-	mprintf("ddev_targp   " FPTR "\n", m.m_ddev_targp);
-	mprintf("logdev_targp " FPTR "\n", m.m_logdev_targp);
+	mprintf("ddev_targp   " FPTR "  (xfs_buftarg)\n", m.m_ddev_targp);
+	mprintf("logdev_targp " FPTR "  (xfs_buftarg)\n", m.m_logdev_targp);
 #else
 	/* old fashion */
 	mprintf("ddev_targ    " FPTR " " FPTR " %04x\n",
@@ -137,9 +133,12 @@ print_xfs_mount(addr, flag)
 		m.m_logdev_targ.pb_targ, m.m_logdev_targ.bd_targ, m.m_logdev_targ.dev);
 #endif
 	mprintf("perag        " FPTR "  (xfs_perag)\n", m.m_perag);
-	mprintf("flags          ");
+	mprintf("flags          %x  ", m.m_flags);
 	mprintbit(mflags, m.m_flags);
 	mprintf("\n");
+	mprintf("qflags         %x  ", m.m_qflags);
+	mprintbit(qflags, m.m_qflags);
+	mprintf("\n");
 
 	if (flag & HFLAG) {
 		int n;
