@@ -3,12 +3,18 @@
 extern const commandtable_t
 	command_pagebuf,
 	command_xfs_alloc_arg,
+	command_xfs_bmalloca,
+	command_xfs_bmbt_irec,
 	command_xfs_bmbt_rec,
 	command_xfs_buftarg,
+	command_xfs_dqhash,
+	command_xfs_dquot,
 	command_xfs_inode,
 	command_xfs_log_item,
 	command_xfs_mount,
 	command_xfs_perag,
+	command_xfs_qm,
+	command_xfs_quotainfo,
 	command_xfs_trans,
 	command_xfs_vfs,
 	command_xlog,
@@ -18,12 +24,18 @@ extern const commandtable_t
 const commandtable_t *commandtable_xfs[] = {
 	&command_pagebuf,
 	&command_xfs_alloc_arg,
+	&command_xfs_bmalloca,
+	&command_xfs_bmbt_irec,
 	&command_xfs_bmbt_rec,
 	&command_xfs_buftarg,
+	&command_xfs_dqhash,
+	&command_xfs_dquot,
 	&command_xfs_inode,
 	&command_xfs_log_item,
 	&command_xfs_mount,
 	&command_xfs_perag,
+	&command_xfs_qm,
+	&command_xfs_quotainfo,
 	&command_xfs_trans,
 	&command_xfs_vfs,
 	&command_xlog,
